[Python-checkins] cpython: Issue #19704: Port test.test_threaded_import to PEP 451

brett.cannon python-checkins at python.org
Fri Dec 13 22:47:28 CET 2013


http://hg.python.org/cpython/rev/dbb9c23e1887
changeset:   87942:dbb9c23e1887
user:        Brett Cannon <brett at python.org>
date:        Fri Dec 13 16:47:19 2013 -0500
summary:
  Issue #19704: Port test.test_threaded_import to PEP 451

files:
  Lib/test/test_threaded_import.py |  12 ++++++------
  1 files changed, 6 insertions(+), 6 deletions(-)


diff --git a/Lib/test/test_threaded_import.py b/Lib/test/test_threaded_import.py
--- a/Lib/test/test_threaded_import.py
+++ b/Lib/test/test_threaded_import.py
@@ -57,7 +57,7 @@
 }
 
 class Finder:
     """A dummy finder to detect concurrent access to its find_module()
     method."""
 
     def __init__(self):
@@ -65,8 +65,8 @@
         self.x = 0
         self.lock = threading.Lock()
 
-    def find_module(self, name, path=None):
-        # Simulate some thread-unsafe behaviour. If calls to find_module()
+    def find_spec(self, name, path=None, target=None):
+        # Simulate some thread-unsafe behaviour. If calls to find_spec()
         # are properly serialized, `x` will end up the same as `numcalls`.
         # Otherwise not.
         assert imp.lock_held()
@@ -80,7 +80,7 @@
     """A dummy finder which flushes sys.path_importer_cache when it gets
     called."""
 
-    def find_module(self, name, path=None):
+    def find_spec(self, name, path=None, target=None):
         sys.path_importer_cache.clear()
 
 
@@ -145,13 +145,13 @@
         # dedicated meta_path entry.
         flushing_finder = FlushingFinder()
         def path_hook(path):
-            finder.find_module('')
+            finder.find_spec('')
             raise ImportError
         sys.path_hooks.insert(0, path_hook)
         sys.meta_path.append(flushing_finder)
         try:
             # Flush the cache a first time
-            flushing_finder.find_module('')
+            flushing_finder.find_spec('')
             numtests = self.check_parallel_module_init()
             self.assertGreater(finder.numcalls, 0)
             self.assertEqual(finder.x, finder.numcalls)
@@ -57,7 +57,7 @@
 
 class Finder:
-    """A dummy finder to detect concurrent access to its find_module()
+    """A dummy finder to detect concurrent access to its find_spec()
     method."""
 

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list